<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AppearancePage</name>
    <message>
        <location filename="../appearancepage.ui" line="22"/>
        <source>Style:</source>
        <translation>Estilo:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="107"/>
        <source>Preview</source>
        <translation>Vista previa</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="117"/>
        <source>Active palette</source>
        <translation>Paleta activa</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="122"/>
        <source>Inactive palette</source>
        <translation>Paleta inactiva</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="127"/>
        <source>Disabled palette</source>
        <translation>Paleta desactivada</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="84"/>
        <location filename="../appearancepage.cpp" line="370"/>
        <source>Default</source>
        <translation>Predeterminada</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="42"/>
        <source>Color scheme:</source>
        <translation>Combinación de colores:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="82"/>
        <source>Standard dialogs:</source>
        <translation>Diálogos estándar:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="71"/>
        <source>Create</source>
        <translation>Crear</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="72"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="73"/>
        <source>Create a Copy</source>
        <translation>Crear una copia</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="74"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="76"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="167"/>
        <location filename="../appearancepage.cpp" line="241"/>
        <location filename="../appearancepage.cpp" line="280"/>
        <source>Enter Color Scheme Name</source>
        <translation>Escribir el nombre de la combinación de colores</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="167"/>
        <location filename="../appearancepage.cpp" line="241"/>
        <location filename="../appearancepage.cpp" line="280"/>
        <source>File name:</source>
        <translation>Nombre del archivo:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="176"/>
        <location filename="../appearancepage.cpp" line="252"/>
        <location filename="../appearancepage.cpp" line="260"/>
        <location filename="../appearancepage.cpp" line="290"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="176"/>
        <location filename="../appearancepage.cpp" line="252"/>
        <location filename="../appearancepage.cpp" line="290"/>
        <source>The color scheme &quot;%1&quot; already exists</source>
        <translation>Ya existe la combinación de colores «%1»</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="194"/>
        <location filename="../appearancepage.cpp" line="217"/>
        <location filename="../appearancepage.cpp" line="275"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="194"/>
        <location filename="../appearancepage.cpp" line="217"/>
        <location filename="../appearancepage.cpp" line="275"/>
        <source>The color scheme &quot;%1&quot; is read only</source>
        <translation>La combinación de colores «%1» es de solo lectura</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="222"/>
        <source>Confirm Remove</source>
        <translation>Confirmar la eliminación</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="223"/>
        <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
        <translation>¿Seguro que quiere eliminar la combinación de colores «%1»?</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="243"/>
        <source>%1 (copy)</source>
        <translation>%1 (copia)</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="260"/>
        <source>Unable to copy file</source>
        <translation>No se puede copiar el archivo</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="371"/>
        <source>Style&apos;s colors</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontConfigDialog</name>
    <message>
        <location filename="../fontconfigdialog.ui" line="14"/>
        <location filename="../fontconfigdialog.cpp" line="74"/>
        <source>Font Configuration</source>
        <translation>Configuración de los tipos de letra</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="29"/>
        <source>Disable automatic hinting for bold fonts</source>
        <translation>Desactivar la optimización automática de los tipos de letra en negrita</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="36"/>
        <source>LCD filter:</source>
        <translation>Filtro LCD:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="43"/>
        <source>Automatic hinting</source>
        <translation>Optimización automática</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="50"/>
        <source>Hinting</source>
        <translation>Optimización</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="67"/>
        <source>Font resolution:</source>
        <translation>Resolución de los tipos de letra</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="110"/>
        <source> dpi</source>
        <translation>ppp</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="83"/>
        <source>Subpixel geometry:</source>
        <translation>Geometría de los subpíxeles:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="90"/>
        <source>Antialiasing</source>
        <translation>Suavizado</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="97"/>
        <source>Hinting style:</source>
        <translation>Estilo de optimización:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="43"/>
        <location filename="../fontconfigdialog.cpp" line="48"/>
        <source>None</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="44"/>
        <source>Slight</source>
        <translation>Ligero</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="45"/>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="46"/>
        <source>Full</source>
        <translation>Completo</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="75"/>
        <source>&lt;i&gt;%1&lt;/i&gt; already exists. Do you want to replace it?</source>
        <translation>&lt;i&gt;%1&lt;/i&gt; ya existe. ¿Quiere reemplazarlo?</translation>
    </message>
</context>
<context>
    <name>FontsPage</name>
    <message>
        <location filename="../fontspage.ui" line="47"/>
        <location filename="../fontspage.ui" line="67"/>
        <location filename="../fontspage.ui" line="86"/>
        <location filename="../fontspage.ui" line="93"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="60"/>
        <source>General:</source>
        <translation>General:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="100"/>
        <source>Fixed width:</source>
        <translation>Ancho fijo:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="125"/>
        <source>Create  fonts.conf</source>
        <translation>Crear fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="132"/>
        <source>Remove fonts.conf</source>
        <translation>Eliminar fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="110"/>
        <source>Remove Font Configuration</source>
        <translation>Eliminar la configuración de los tipos de letra</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="111"/>
        <source>Are you sure you want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation>¿Seguro que quiere eliminar &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
</context>
<context>
    <name>InterfacePage</name>
    <message>
        <location filename="../interfacepage.ui" line="35"/>
        <source>Double click interval:</source>
        <translation>Intervalo de doble clic:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="42"/>
        <source>Cursor flash time:</source>
        <translation>Tiempo de parpadeo del cursor:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="49"/>
        <source>ComboBox effect:</source>
        <translation>Efecto del cuadro combinado:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="56"/>
        <source>ToolTip effect:</source>
        <translation>Efecto de la información emergente:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="63"/>
        <source>ToolBox effect:</source>
        <translation>Efecto de la caja de herramientas:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="70"/>
        <location filename="../interfacepage.ui" line="80"/>
        <source> ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="94"/>
        <location filename="../interfacepage.ui" line="111"/>
        <location filename="../interfacepage.ui" line="133"/>
        <location filename="../interfacepage.ui" line="157"/>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="99"/>
        <location filename="../interfacepage.ui" line="116"/>
        <location filename="../interfacepage.ui" line="138"/>
        <location filename="../interfacepage.ui" line="162"/>
        <source>Animate</source>
        <translation>Animar</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="121"/>
        <location filename="../interfacepage.ui" line="167"/>
        <source>Fade</source>
        <translation>Fundir</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="146"/>
        <source>Menu effect:</source>
        <translation>Efecto del menú:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="175"/>
        <source>Enable gui effects</source>
        <translation>Activar los efectos de la interfaz</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="182"/>
        <source>Dialog buttons layout:</source>
        <translation>Distribución de los botones de diálogo:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="192"/>
        <source>Keyboard scheme:</source>
        <translation>Distribución del teclado</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="202"/>
        <source>Menus have icons</source>
        <translation>Menús con iconos</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="209"/>
        <source>Dialog buttons have icons</source>
        <translation>Botones de diálogo con iconos</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="219"/>
        <source>Activate item on single-click</source>
        <translation>Activar elementos con un solo clic</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="229"/>
        <source>Toolbar button style:</source>
        <translation>Estilo de los botones de la barra de herramientas:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="239"/>
        <source>Mouse wheel scroll lines:</source>
        <translation>Líneas de desplazamiento de la rueda del ratón:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="256"/>
        <source>Show shortcut underlines</source>
        <translation>Mostrar el subrayado de los accesos rápidos</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="266"/>
        <source>Show shortcuts in context menus</source>
        <translation>Mostrar los accesos directos en los menús contextuales</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="55"/>
        <source>Only display the icon</source>
        <translation>Mostrar solo el icono</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="56"/>
        <source>Only display the text</source>
        <translation>Mostrar solo el texto</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="57"/>
        <source>The text appears beside the icon</source>
        <translation>Mostrar el texto a lado del icono</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="58"/>
        <source>The text appears under the icon</source>
        <translation>Mostrar el texto debajo del icono</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="59"/>
        <source>Follow the application style</source>
        <translation>Seguir el estilo de la aplicación</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Qt6 Configuration Tool</source>
        <translation>Herramienta de configuración de Qt6</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>The application is not configured correctly.</source>
        <translation>No se ha configurado correctamente la aplicación.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="68"/>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="51"/>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Fonts</source>
        <translation>Tipos de letra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="53"/>
        <source>Icon Theme</source>
        <translation>Tema de iconos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="54"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="56"/>
        <source>Style Sheets</source>
        <translation>Hojas de estilo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="58"/>
        <source>Troubleshooting</source>
        <translation>Solución de problemas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="65"/>
        <source>Version: %1</source>
        <translation>Versión: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="111"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="120"/>
        <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
        <translation>Elimine la variable de entorno &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; (valor actual: &lt;b&gt;%1&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation>No se ha configurado la variable de entorno &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; (valores obligatorios: &lt;b&gt;qt6ct&lt;/b&gt; o &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation>No se ha configurado correctamente la variable de entorno &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; (valor actual: &lt;b&gt;%1&lt;/b&gt;, valores requeridos: &lt;b&gt;qt6ct&lt;/b&gt; o &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Unable to find &lt;b&gt;libqt6ct-style.so&lt;/b&gt;</source>
        <translation>No se puede encontrar &lt;b&gt;libqt6ct-style.so&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <source>The &lt;b&gt;%1&lt;/b&gt; plugin is compiled against incompatible Qt version (%2).</source>
        <translation>El complemento &lt;b&gt;%1&lt;/b&gt; se ha compilado con una versión de Qt incompatible (%2).</translation>
    </message>
</context>
<context>
    <name>PaletteEditDialog</name>
    <message>
        <location filename="../paletteeditdialog.ui" line="14"/>
        <source>Palette Editor</source>
        <translation>Editor de la paleta</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="79"/>
        <source>Reset palette</source>
        <translation>Restablecer la paleta</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="29"/>
        <source>Build inactive palette</source>
        <translation>Generar la paleta inactiva</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="36"/>
        <source>Build disabled palette</source>
        <translation>Generar la paleta desactivada</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Active</source>
        <translation>Activa</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Inactive</source>
        <translation>Inactiva</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Desactivada</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Dark</source>
        <translation>Oscuro</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Window text</source>
        <translation>Texto de la ventana</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Button background</source>
        <translation>Fondo del botón</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Bright</source>
        <translation>Brillante</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Less bright</source>
        <translation>Menos brillante</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Less dark</source>
        <translation>Menos oscuro</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Shadow</source>
        <translation>Sombra</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Bright text</source>
        <translation>Texto brillante</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Button text</source>
        <translation>Texto del botón</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Normal text</source>
        <translation>Texto normal</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Normal background</source>
        <translation>Fondo normal</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Highlight</source>
        <translation>Resaltado</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Highlighted text</source>
        <translation>Texto resaltado</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Visited link</source>
        <translation>Enlace visitado</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Default</source>
        <translation>Por defecto</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Tooltip background</source>
        <translation>Fondo de la información emergente</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Tooltip text</source>
        <translation>Texto de la información emergente</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Link</source>
        <translation>Enlace</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Alternate background</source>
        <translation>Fondo alternativo</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Placeholder text</source>
        <translation>Texto de relleno</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="97"/>
        <source>Accent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="110"/>
        <source>Select Color</source>
        <translation>Seleccionar el color</translation>
    </message>
</context>
<context>
    <name>PreviewForm</name>
    <message>
        <location filename="../previewform.ui" line="14"/>
        <source>Preview Window</source>
        <translation>Ventana de vista previa</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="27"/>
        <source>Tab 1</source>
        <translation>Pestaña 1</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="36"/>
        <source>PushButton</source>
        <translation>Botón</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="65"/>
        <source>Tab 2</source>
        <translation>Pestaña 2</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="74"/>
        <source>RadioButton</source>
        <translation>Botón de opción</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="84"/>
        <source>CheckBox</source>
        <translation>Casilla de verificación</translation>
    </message>
</context>
<context>
    <name>QSSEditorDialog</name>
    <message>
        <location filename="../qsseditordialog.cpp" line="46"/>
        <source>%1 - Style Sheet Editor</source>
        <translation>%1 - Editor de hojas de estilo</translation>
    </message>
    <message>
        <location filename="../qsseditordialog.ui" line="14"/>
        <source>Style Sheet Editor</source>
        <translation>Editor de hojas de estilo</translation>
    </message>
</context>
<context>
    <name>QSSPage</name>
    <message>
        <location filename="../qsspage.ui" line="23"/>
        <source>Create</source>
        <translation>Crear</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="66"/>
        <location filename="../qsspage.cpp" line="51"/>
        <location filename="../qsspage.cpp" line="86"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="76"/>
        <location filename="../qsspage.cpp" line="53"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="33"/>
        <location filename="../qsspage.cpp" line="55"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="52"/>
        <source>Create a Copy</source>
        <translation>Crear una copia</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="91"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="105"/>
        <location filename="../qsspage.cpp" line="250"/>
        <source>File name:</source>
        <translation>Nombre del archivo:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="105"/>
        <location filename="../qsspage.cpp" line="250"/>
        <source>Enter Style Sheet Name</source>
        <translation>Escribir el nombre de la hoja de estilo</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="116"/>
        <location filename="../qsspage.cpp" line="217"/>
        <location filename="../qsspage.cpp" line="225"/>
        <location filename="../qsspage.cpp" line="262"/>
        <location filename="../qsspage.cpp" line="270"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="116"/>
        <source>The file &quot;%1&quot; already exists</source>
        <translation>Ya existe el archivo «%1»</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="150"/>
        <source>Confirm Remove</source>
        <translation>Confirmar la eliminación</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="151"/>
        <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
        <translation>¿Seguro que quiere eliminar la hoja de estilo «%1»?</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="207"/>
        <source>Rename Style Sheet</source>
        <translation>Renombrar la hoja de estilo</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="207"/>
        <source>Style sheet name:</source>
        <translation>Nombre de la hoja de estilo:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="217"/>
        <location filename="../qsspage.cpp" line="262"/>
        <source>The style sheet &quot;%1&quot; already exists</source>
        <translation>Ya existe la hoja de estilo «%1»</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="225"/>
        <source>Unable to rename file</source>
        <translation>No se puede cambiar el nombre del archivo</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="252"/>
        <source>%1 (copy).qss</source>
        <translation>%1 (copia).qss</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="270"/>
        <source>Unable to copy file</source>
        <translation>No se puede copiar el archivo</translation>
    </message>
</context>
<context>
    <name>TroubleshootingPage</name>
    <message>
        <location filename="../troubleshootingpage.ui" line="20"/>
        <source>Ignored applications:</source>
        <translation>Aplicaciones ignoradas:</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="29"/>
        <source>Add...</source>
        <translation>Añadir...</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="40"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="73"/>
        <source>Do not apply any styles and color schemes for the listed applications.</source>
        <translation>No aplicar estilos ni combinaciones de colores para las aplicaciones enumeradas.</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="82"/>
        <source>Make top-level widgets use pure raster surfaces, and do not support non-native GL-based child widgets.</source>
        <translation>Hacer que los componentes de nivel superior usen superficies rasterizadas puras y no admitan componentes secundarios no nativos basados en GL.</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="85"/>
        <source>Force raster surface</source>
        <translation>Forzar la superficie rasterizada</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="63"/>
        <source>Select Application</source>
        <translation>Seleccionar la aplicación</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="63"/>
        <source>Executable files (*)</source>
        <translation>Archivos ejecutables (*)</translation>
    </message>
</context>
</TS>
